<?php
define("MSG_BAD_CREDENTIALS","Les identifiants fournis (nom d’utilisateur ou mot de passe) sont invalides.");
define("MSG_BAD_DMUX","Impossible d'ajouter le Dmux %s, avec la grille %s et les ports %d");
define("MSG_BAD_THRESHOLD_VALUE","La valeur de seuil %s est incorrecte pour le champs: %s");
define("MSG_BAD_ROTAU_IP","Impossible de se connecter au ROTAU d'adresse %s");
define("MSG_CHINESE","中文");
define("MSG_CONNECTION","Connexion");
define("MSG_COPYRIGHT_SHORT","Copyright © 2025 VIAVI. Tous droits réservés.");
define("MSG_ENGLISH","English");
define("MSG_ERROR_ADD_LOCALISATION_ERROR","Erreur d ajout de localisation!"); 
define("MSG_ERROR_ALARM_UNDEFINED","Alarme inconnue");
define("MSG_ERROR_ALARM_FETCH_FAILED","Echec lors de la récupération d'une alarme: ");
define("MSG_ERROR_APPLY_DATABASE_PATCH_FAILURE","Les patches de la base de données n'ont pas pu être appliqués!");
define("MSG_ERROR_CLEAR_TEST_ALARM","Erreur lors de la suppression des alarmes du test!");
define("MSG_ERROR_COMMIT_TRANSACTION","Echec de l'enregistrement car la transaction n'a pas pu être validée!");
define("MSG_ERROR_CONNECTION_FAILED","Echec de connexion!");
define("MSG_ERROR_COPY_FAILED","Erreur de copie du fichier!");
define("MSG_ERROR_COULD_NOT_ACQUIRE_LOCK","Echec d'obtention du verrou!");
define("MSG_ERROR_COULD_NOT_CREATE_FILE","Echec de création du fichier: ");
define("MSG_ERROR_COULD_NOT_CREATE_SNAPSHOT","Echec de création du Snapshot! ");
define("MSG_ERROR_COULD_NOT_CREATE_BACKUP","Echec de création du backup de l'OTU!");
define("MSG_ERROR_CREATE_DATABASE_MODEL_FAILURE","Le modèle de base de données n'a pas pu être créé!");
define("MSG_ERROR_COULD_NOT_CREATE_GPS_FILE","Echec de création du fichier GPS!");
define("MSG_ERROR_DELETE_LINK","Erreur lors de la suppression de la liaison!");
define("MSG_ERROR_DELETE_OPTICAL_ALARM_FAILED","Echec lors de la suppression des alarmes sur un test!");
define("MSG_ERROR_DELETE_OPTICAL_ALARM_ON_TEST_FAILED","Echec lors de la suppression des alarmes sur le test %d!");
define("MSG_ERROR_DELETE_TEST","Erreur lors de la suppression de test!");
define("MSG_ERROR_DTO_NOT_FOUND","La classe Dto %s n'a pas été trouvée.");
define("MSG_ERROR_DTO_NOT_MAPPED","Les données traitées n'ont pas de correspondance en base de données!");
define("MSG_ERROR_DTO_PROPERTY_NOT_FOUND","La propriété %s de la classe %s n'a pas été trouvée.");
define("MSG_ERROR_EXECUTE_STATEMENT","Echec d'éxécution de la requête!");
define("MSG_ERROR_FAILED_TO_CHANGE_USER_PASSWORD","Echec du changement de mot de passe de l'utilisateur!");
define("MSG_ERROR_FAILED_TO_UPDATE_USER_PASSWORD_FILE","Echec de la mise à jour du fichier de mots de passe!");
define("MSG_ERROR_FILE_NOT_FOUND","Le fichier n'a pas été trouvé!");
define("MSG_ERROR_INCOHERENT_FONCTION","Fonction Incohérente"); 
define("MSG_ERROR_INVALID_ALARM_NAME","Echec lors de la récupération d'une alarme, nom de fichier invalide: ");
define("MSG_ERROR_INVALID_CONFIG","Paramètres de configuration du media incorrects.");
define("MSG_ERROR_INVALID_LICENSE","License Invalide!");
define("MSG_ERROR_INVALID_FILE","Fichier invalide!");
define("MSG_ERROR_INVALID_HOST_NAME","Nom d'hôte invalide: ne doit pas être vide et ne doit pas dépasser 28 caractères!");
define("MSG_ERROR_INVALID_IPV4","Addresse Ipv4 incorrecte!");
define("MSG_ERROR_INVALID_IPV4GATEWAY","Addresse Ipv4 de la passerelle incorrecte!");
define("MSG_ERROR_INVALID_IPV4SUBNET","Addresse Ipv4 du maque de sous réseau incorrecte!");
define("MSG_ERROR_INVALID_IPV6","Addresse Ipv6 incorrecte!");
define("MSG_ERROR_INVALID_IPV6GATEWAY","Addresse Ipv6 de la passerelle incorrecte!");
define("MSG_ERROR_INVALID_LINK_ID","Identifiant de liaison non valide!");
define("MSG_ERROR_INVALID_LINK_NAME","Nom de liaison invalide: ne doit pas être vide et ne doit pas dépasser 80 caractères!");
define("MSG_ERROR_INVALID_MODEM_TYPE","Type de modem invalid!");
define("MSG_ERROR_INVALID_MODULE_SELECTED","Identifiant de module invalide.");
define("MSG_ERROR_INVALID_OPERATION_STATUS","Résultat invalide pour l'opération exécutée!");
define("MSG_ERROR_INVALID_PORT_OUT","Port de sortie invalide!");
define("MSG_ERROR_INVALID_PORT","Port invalid!");
define("MSG_ERROR_INVALID_TEST_THRESHOLD_PARAMETERS","Paramètres des seuils du test invalides!");
define("MSG_ERROR_INVALID_USER_NEW_CREDENTIALS","Nouveaux identifiants de l'utilisateur non valides!");
define("MSG_ERROR_IO_EXCEPTION","Erreur d'entrée/sortie!");
define("MSG_ERROR_LAST_MARKER_BADLY_SET","Dernier marqueur mal positionné!");
define("MSG_ERROR_LINK_ALREADY_EXIST","Une liaison existe déjà (ou elle est en cours de suppression)!");
define("MSG_ERROR_LINK_HARDWARE_CONFIG","La liaison ne peut pas être ajouté car la configuration du module OTDR ou du commutateur est invalide!");
define("MSG_ERROR_LINK_NO_MODULE","Aucun module OTDR n'est configuré!");
define("MSG_ERROR_LINK_NOT_FOUND","Liaison inconnue");
define("MSG_ERROR_LINK_UNKNOWN","Liaison Inconnue!"); 
define("MSG_ERROR_MEASURE_BAD_TIME","Echec de lancement de la mesure car la durée est invalide!");
define("MSG_ERROR_MEASURE_BAD_TIMESLOT","Echec de lancement de la mesure car on est dans la période inactive  (timeslot)");
define("MSG_ERROR_MEASURE_FAILED","Echec du lancement de la mesure");
define("MSG_ERROR_MEASURE_NOT_PROGRAMMED","La mesure n'a pas pu être programmée");
define("MSG_ERROR_MEDIA","Echec: ");
define("MSG_ERROR_MISSING_TEST_THRESHOLD_PARAMETERS","Paramètres des seuils du test absents!");
define("MSG_ERROR_MISSING_OTDR_TRACE","Courbe du test OTDR non trouvée!");
define("MSG_ERROR_MODEM_NOT_AVAILABLE","Le Modem n'est pas disponible!");
define("MSG_ERROR_MOD_MISSING","Module Manquant!"); 
define("MSG_ERROR_NO_BACKUP_FOUND","Echec de la restauration, le fichier backup n'a pas été trouvé!");
define("MSG_ERROR_NO_LINE_STRING","Aucun objet de type LineString trouvé dans le kml!");
define("MSG_ERROR_NO_LINE_STRING_COORDINATES","Aucune coordonnée trouvée dans le kml!");
define("MSG_ERROR_NO_PLACEMARK","Aucun repère de type Placemark trouvé dans le kml!");
define("MSG_ERROR_ONE_MEASURE_ON_DEMAND","Une seule mesure peut-être lancée simultanément!");
define("MSG_ERROR_ONE_TEST_ON_DEMAND","Un seul test sur demande peut-être lancé simultanément!");
define("MSG_ERROR_ONLY_ONE_TEST_SETUP","Un seul test de surveillance peut être configuré simultanément!");
define("MSG_ERROR_OPENING_DATABASE","Echec d'ouverture de la base de donnée!");
define("MSG_ERROR_OPENING_SOCKET","Echec de connexion à l'application OTU!");
define("MSG_ERROR_OPENING_TRANSACTION","Echec de l'enregistrement car la transaction n'a pas pu être ouverte!");
define("MSG_ERROR_OPERATION_ALLREADY_RUNNING","Echec, l'opération est déjà en cours!");
define("MSG_ERROR_OPTION_MODEM_NOT_SET","L'option modem n'est pas activée!");
define("MSG_ERROR_OTU_APPLICATION_NOT_AVAILABLE","L'application OTU n'est pas disponible!");
define("MSG_ERROR_OTU_APPLICATION_STARTING","L'application OTU est en cours de démarrage...");
define("MSG_ERROR_OTU_APPLICATION_RESCUE","L'OTU est en mode RESCUE.");
define("MSG_ERROR_OTU_APPLICATION_REBOOTING","L'application OTU est en cours de re-démarrage...");
define("MSG_ERROR_OTU_APPLICATION_UPGRADE","L'application OTU est en cours d'upgrade...");
define("MSG_ERROR_OTU_AUTHENTIFICATION_FAILURE","Echec d'authentification sur le parser de l'OTU!");
define("MSG_ERROR_PARAM_MISSING","Paramètre Manquant!");
define("MSG_ERROR_PORT_OTU","Echec de la récupération du port de l'application OTU!");
define("MSG_ERROR_READING_APC","Erreur de lecture dans la mémoire partagée");
define("MSG_ERROR_READING_SOCKET","Erreur de communication avec l'application OTU!");
define("MSG_ERROR_REG_MEAS_FAILED","Echec d'enregistrement de ma mesure!"); 
define("MSG_ERROR_REF_FILE_PARAMETER_ERROR","Erreur de paramètre avec le fichier de référence");
define("MSG_ERROR_REMOTE_HOST_ATTEMPT_TO_SEND_DATA","Tentative d'un hote distant d'envoyer des données!");
define("MSG_ERROR_ROLLBACK_TRANSACTION","Echec de l'annulation de la sauvegarde!");
define("MSG_ERROR_SAA_ALLREADY_RUNNING","Echec, la configuration de SmartAccessAnywhere est déjà en cours!");
define("MSG_ERROR_SAA_CONNECTION_FAILED","Echec de connection Smart Access Anywhere!");
define("MSG_ERROR_SNMP_INVALID_COMMUNITY","Nom de communauté invalide!");
define("MSG_ERROR_SNMP_INVALID_HEARTBEAT_PERIOD","Periode de battement de coeur snmp invalide");
define("MSG_ERROR_SNMP_INVALID_PORT","Numéro de port invalide!");
define("MSG_ERROR_SNMP_INVALID_SERVER_NAME","Nom ou addresse invalide du manager");
define("MSG_ERROR_SNMP_INVALID_TEST_MESSAGE","Message du trap invalide.");
define("MSG_ERROR_START_EMAIL_TEST","L'envoi de l'Email a échoué: ");
define("MSG_ERROR_START_SMS_TEST","L'envoi du SMS a échoué: ");
define("MSG_ERROR_START_MEASURE","Echec de lancement de la mesure! ");
define("MSG_ERROR_STOP_MEASURE","Echec d'arrêt de la mesure ");
define("MSG_ERROR_SWITCH_BUFFER_ERROR","Buffer de commutation erroné!"); 
define("MSG_ERROR_SWITCH_BUFFER_SIZE","Taille du buffer de commutation erronée!"); 
define("MSG_ERROR_SYSTEM_USER_PASSWORD_CANNOT_BE_CHANGED","Le mot de passe de l'utilisateur system ne peut pas être changé!");
define("MSG_ERROR_TABLE_NOT_FOUND","La table n'a pas été trouvée en base de données!");
define("MSG_ERROR_TEST_ADD_ERROR","Echec d'ajout du test!");    
define("MSG_ERROR_TEST_ADD_LOC","Problème avec la localisation du test!");
define("MSG_ERROR_TEST_ALLOCATE_MEMORY","Problème pour allouer la mémoire nécessaire au test!");
define("MSG_ERROR_TEST_ALREADY_EXIST","Un test existe déjà sur la liaison ou il est en cours de suppression!");
define("MSG_ERROR_TEST_BAD_MARKER_BUFFER","Mauvais buffer de marqueurs pour le test!");
define("MSG_ERROR_TEST_BAD_TIMESLOT","Echec du test car on est dans la période inactive (timeslot)");
define("MSG_ERROR_TEST_FAILED","Echec du lancement du test sur demande");
define("MSG_ERROR_TEST_FUNCT","Fonctions du test incoherentes!");
define("MSG_ERROR_TEST_FUNCT_MISS","Fonction du test manquante!");
define("MSG_ERROR_TEST_MISS_LINK","Liaison du test manquante!");
define("MSG_ERROR_TEST_MISS_REF_TRACE","Courbe OTDR de reference manquante!");
define("MSG_ERROR_TEST_NO_PARAM","Paramètres du test manquants!");
define("MSG_ERROR_TEST_NOT_FOUND","Test de surveillance inconnu!");
define("MSG_ERROR_TEST_NOT_PROGRAMMED","Le test n'a pas pu être éxécuté!");
define("MSG_ERROR_TEST_OK","Ajout du test avec succès.");
define("MSG_ERROR_TEST_REF_PARAM","Problème avec les paramètres de la trace otdr de référence!");
define("MSG_ERROR_TEST_SAVE_CONFIG","Problème pour enregistrer la configuration du test!");
define("MSG_ERROR_TEST_SAVE_INFO","Problème pour enregistrer les informations du test!");
define("MSG_ERROR_TEST_SAVE_DESC","Problème pour enregistrer la description du test!");
define("MSG_ERROR_TEST_SIZE_BUFFER_MARKER","Mauvaise taille de buffer pour le test");
define("MSG_ERROR_TEST_TEST_RUNNING","Test en cours, impossible de modifier le test!");
define("MSG_ERROR_TEST_TOO_MUCH_LOC","Trop de courbes localisations!");
define("MSG_ERROR_TEST_TOO_MUCH_TESTS","Trop de tests!");
define("MSG_ERROR_TEST_TYPE","Type de test inconnu!");
define("MSG_ERROR_TEST_UNDEFINED","erreur indéfinie");
define("MSG_ERROR_TEST_UNDEFINED_TEST","Test non défini!");
define("MSG_ERROR_TEST_UPDATE_FAILED","Echec de la mise à jour du test!");
define("MSG_ERROR_TOO_MANY_LINE_STRING","Le fichier ne doit contenir qu'une seule route avec un seul objet de type LineString");
define("MSG_ERROR_UNDEFINED","Erreur non définie");
define("MSG_ERROR_USER_PASSWORD_NOT_FOUND","L'utilisateur avec le mot de passe donné n'a pas été trouvé!");
define("MSG_ERROR_WRITING_APC","Erreur d'écriture dans la mémoire partagée");
define("MSG_ERROR_WRITTING_SOCKET","Erreur d'écriture sur la socket du parser!");
define("MSG_ERROR_WRONG_FONCTION","Fonction du module erronée!"); 
define("MSG_ERROR_WRONG_LASER","Longueur d'onde erronée!"); 
define("MSG_ERROR_WRONG_PULSE","Mauvaise impulsion!");
define("MSG_ERROR_WRONG_RANGE","Mauvaise portée!"); 
define("MSG_ERROR_WRONG_RES","Mauvaise résolution!"); 
define("MSG_FRENCH","Français");
define("MSG_INVALID_LOG_LEVEL_PARAMETER","Niveau de log invalide, valeurs possibles: %s");
define("MSG_INVALID_VALUE_EXCEPTION","Valeur incorrecte pour le parametre: %s");
define("MSG_INVALID_STATUS","Etat invalide pour l'opération!");
define("MSG_IO_EXCEPTION","Erreur d'entrée/sortie sur le disque!");
define("MSG_LANGUAGE","Langue");
define("MSG_LINK","Liaison");
define("MSG_LOGIN","Identifiant");
define("MSG_LOGIN_WINDOW_TITLE","Connexion");
define("MSG_MEAS_ADD_OK","Ajout de la mesure effectué."); 
define("MSG_MEASURE_AVAILABLE","Resultat de la mesure disponible.");
define("MSG_MEASURE_INIT","Initialisation de la mesure...");
define("MSG_MEASURE_IN_PROGRESS","Mesure en cours...");
define("MSG_MEASURE_WAITING","Attente avant de lancer la mesure...");
define("MSG_NO_JS","JavaScript est nécessaire pour lancer l’application. Veuillez activer le JavaScript dans les options de votre navigateur.");
define("MSG_PORT","Port");
define("MSG_PARSER_COMMAND_FAILURE","Echec d'exécution de la commande!");
define("MSG_PARSER_COMMAND_TIMEOUT","Echec d'exécution de la commande: la connexion interne à l'OTU a échoué!");
define("MSG_PASSWORD","Mot de passe");
// define("MSG_SEND_SMS_MESSAGE","SMS de test envoye par l'OTU: %s");
// define("MSG_SEND_SNMP_MESSAGE","Test envoyé par l'OTU: %s");
define("MSG_SOCKET_ERROR","Erreur avec la socket de connexion avec le parser!");
define("MSG_SPLASH_SCREEN_MESSAGE","Chargement en cours...");
// define("MSG_TEST_EMAIL","Test envoyé par l'OTU: ");

//OTU resources
define("OTU_RES_NAME_BASE","OTU");   // Associes a la ressource UNIT
define("OTU_RES_NAME_EMAIL","Email");
define("OTU_RES_NAME_EXTERNAL_OTAU","OTAU externe");
define("OTU_RES_NAME_INTERNAL_OTAU","OTAU interne");
define("OTU_RES_NAME_MODEM","Modem");
define("OTU_RES_NAME_NETWORK","Réseau");   	   // Associes a la ressource COM
define("OTU_RES_NAME_NETWORK_MODEM","Problème réseau avec le Modem");
define("OTU_RES_NAME_OPTICAL_MODULE","Module OTDR");
define("OTU_RES_NAME_RELAY_CARD","Carte relais");
define("OTU_RES_NAME_SERVER","Serveur");
define("OTU_RES_NAME_SMS","SMS");
define("OTU_RES_NAME_UNKNOWN","Inconnu");
define("OTU_RES_TIMESTAMP","Date");
define("OTU_RES_SEVERITY","Criticité");
define("OTU_RES_LINK","Liaison");
define("OTU_RES_DESCRIPTION","Description");


//OTU alarms
define("ACQUISITION_TIME","Temps d'acquisition");
define("ALARM_SWITCH","Erreur interne dans le commutateur");
define("ALARM_MODULE","Erreur interne dans le module OTDR");
define("AUTOTEST_TEST","Test de l'autotest");
define("BACK_TO_NORMAL_STATE","Retour à la normale");
define("END_OF_SURVEY","Fin des vérifications");
define("HARD_DISK_FREE_SPACE","Place libre sur le disque");
define("HEART_BEAT_SENT_TO_ONMS","Battement de coeur envoyé à ONMS");
define("INCOHERENCE_PROBLEM_WITH_RAMAN_ACQUISITION_MODE","Incohérence avec le mode d'acquisition RAMAN");
define("INITIALISATION_FAILURE_DUE_TO_HARDWARE","Problème hardware");
define("INITIALISATION_FAILURE_DUE_TO_SOFTWARE","Problème logiciel");
define("INJECTION_FAILURE","Défaut d'injection");
define("INNER_APPLICATION_COMMUNICATION_PROBLEM","Problème de communication en interne sur l'OTU");
define("LINK_BREAK","Coupure de fibre");
define("LINKS_BACK_TO_AVAILABLE","Les liaisons sont de nouveau disponibles");
define("LOCAL_MODE","Mode local");
define("MISSING_REFERENCE_FILE","Fichier de référence absent!");
define("MODULE_AUTOCONFIGURATION","Autoconfiguration du module OTDR");
define("MODULE_TEMPERATURE","Problème de température du module");
define("MONITORING_CYCLE","Cycle de surveillance");
define("MONITORING_TEST_DRIFT","Dérive du test de surveillance");
define("NO_PROBLEM_DETECTED","Aucun problème détecté");
define("NON_REFLECTIVE_FAILURE","Défaut non réfléchissant");
define("OTDR_TRACE_STORAGE","Problème de stockage pour la courbe OTDR");
define("OTU_ALARM","Alarme %s");
define("OTU_ALARM_CONFIRMEE","Alarme confirmée");
define("OTU_ALARM_GENERIC_MESSAGE","Alarme générique"); 
define("OTU_ALARM_NON_CONFIRMEE","Alarme non confirmée"); 
define("OTU_ALARM_OVERFLOW","Dépassement du nombre d'alarme maximum");
define("OTU_ALARM_REBUID_CLEAR","Effacement des alarmes après une reconstruction");
define("OTU_ALARM_HDD_FAILED","Echec disque dur");
define("OTU_ALARM_HDD_FAILED_USE_BACKUP","Echec disque dur: utilisation du disque de backup");
define("OTU_ALARM_SEQ_STOPPED","Séquenceur arrêté");
define("OTU_ALARM_CLEAR","Retour à la normale");
define("OTU_ALARM_CRITICAL","Critique");
define("OTU_ALARM_INDETERMINATE","Indéterminé");
define("OTU_ALARM_MAJOR","Majeur");
define("OTU_ALARM_MINOR","Mineur");
define("OTU_ALARM_WARNING","Avertissement");
define("OTU_SYST_ALARM_POWER_FAILURE","Perte d'alimentation");
define("PEAK","Pic");
define("PERSISTENT_FAILURE","Persistence du défaut");
define("PON_FAILURE","Echec du test PON");
define("OTU_SYST_REFERENCE_DRIFT_FAILURE","Dérive de la courbe de référence");
define("RAMAN_POWER_DETECTION","Puissance RAMAN");
define("RAMAN_POWER_DECREASE","Baisse de la puissance RAMAN");
define("REBOOT","Reboot");
define("REFLECTIVE_FAILURE","Défaut réflectif");
define("SIGNAL_DETECTED_ON_FIBER","Signal détecté sur la fibre");
define("SPLICE_FAILURE","Echec de détection de l'épissure");
define("SWITCH_AUTOCONFIGURATION","Autoconfiguration du commutateur");
define("SYSTEM_FILE","Fichier système");
define("TEMPORARY_PROBLEM","Problème temporaire");
define("TEST_MEDIA","Test des media");
define("TIMEOUT_ON_MONITORING_TEST_CYCLE","Dépassement du temps imparti pour le lancement du test de surveillance");
define("THRESHOLD_LEVEL_EXCEEDED","Dépassement de niveau");
define("CONNECTOR_FAILURE","Connecteur");
define("CONNECTOR_FIBER_CUT_FAILURE","Coupure fibre (Connecteur)");
define("CONNECTOR_ATTENUATION_FAILURE","Dépassement de niveau (Connecteur)");
define("SPLICE_BREAK","Epissure cassée ou APC patchcord déconnecté");
define("CONNECTOR_BREAK","Patchcord déconnecté ou courbure excessive");
define("FIBER_BREAK","Coupure Fibre");
define("SPLICE_ATTENUATION","Courbure fibre au niveau d'une épissure ou d'un patchcord APC");
define("CONNECTOR_ATTENUATION","Courbure au niveau d'un connecteur, connecteur sale ou mal connecté");
define("FIBER_ATTENUATION","Courbure fibre");
define("NEW_REFERENCE_REQUIRED","Fibre modifiée: Requiert une nouvelle référence");
define("UNKNOW_ALARM","Alarme inconnue");
define("UNKNOWN_CAUSE","Cause inconnue");
?>
